##MDS, Mantel, MRDM (multiple regression of distance matrices)

##READING IN DISTANCE MATRICES 
#this is to take in lower triangle distance matrix 
#I construct a matrix shell in excel - Distance_matrices_forR.xlsx to get in Arlequin distances
#Genodive output is a square matrix
library(vegan)
#hapdist
Hapdist10<-read.table("Hapdist_N10.txt")  
Hapdist10<-as.data.frame(Hapdist10)
Hapdist10<-as.dist(Hapdist10)
Hap10_mds<-metaMDS(Hapdist10, autotransform = FALSE, zerodist = "add", center)

plot(Hap10_mds, main="MDS of Fst from haplotype identity")
text(Hap10_mds, pos = 3, offset = .25, cex=0.75)

#phist
PhiSTdist10<-read.table("PhiSt_N10.txt")  
PhiSTdist10<-as.data.frame(PhiSTdist10)
PhiSTdist10<-as.dist(PhiSTdist10)
PhiST10_mds<-metaMDS(PhiSTdist10, autotransform = FALSE, zerodist = "add", center)

plot(PhiST10_mds, main="MDS of PhiST using Tam Nei dists")
text(PhiST10_mds, pos = 3, offset = .25, cex=0.75)

#Gst''
GSTdist10<-read.table("Gst_dist.txt")  
GSTdist10<-as.data.frame(GSTdist10)
GSTdist10<-as.dist(GSTdist10)
GST10_mds<-metaMDS(GSTdist10, autotransform = FALSE, zerodist = "add", center)

plot(GST10_mds, main="MDS of GST''")
text(GST10_mds, pos = 3, offset = .25, cex=0.75)

#Jost D
Jostdist10<-read.table("Jost_dist.txt")  
Jostdist10<-as.data.frame(Jostdist10)
Jostdist10<-as.dist(Jostdist10)
Jost10_mds<-metaMDS(Jostdist10, autotransform = FALSE, zerodist = "add", center)

par(mfrow = c(1,1))
plot(Jost10_mds, main="MDS of JostD")
text(Jost10_mds, pos = 3, offset = .25, cex=0.75)


#plotting all 4
par(mfrow = c(2,2))
plot(PhiST10_mds, main="MDS of PhiST using Tam Nei dists")
text(PhiST10_mds, pos = 3, offset = .25, cex=0.75)
plot(Hap10_mds, main="MDS of Fst from haplotype identity")
text(Hap10_mds, pos = 3, offset = .25, cex=0.75)
plot(GST10_mds, main="MDS of GST''")
text(GST10_mds, pos = 3, offset = .25, cex=0.75)
plot(Jost10_mds, main="MDS of JostD")
text(Jost10_mds, pos = 3, offset = .25, cex=0.75)

#Mantel tests and MRDM
library(vegan)
library(lmPerm)

#read in phi distances
PhiSTdist10<-read.table("PhiSt_N10.txt")  
PhiSTdist10<-as.data.frame(PhiSTdist10)
PhiSTdist10<-as.dist(PhiSTdist10)
#read in GSTdist10, Jostdist10, as above

#read in euclidean distances - similar as above
Eucdist10<-read.table("Eucdist_N10.txt")  
Eucdist10<-as.data.frame(Eucdist10)
Eucdist10<-as.dist(Eucdist10)

#read in overwater distances
OWdist10<-read.table("OWaterdist.txt")  
OWdist10<-as.data.frame(OWdist10)
OWdist10<-as.dist(OWdist10)

#compare distances
plot(Eucdist10, PhiSTdist10)
plot(log(Eucdist10), log((PhiSTdist10+0.05)/(1-(PhiSTdist10+0.05))))  #Roussets transformation with small value added to avoid neg numbs
lm_Phi_Euc<-lm(PhiSTdist10 ~Eucdist10)
lm_logRousPhi_logEuc<-lm(log((PhiSTdist10+0.05)/(1-(PhiSTdist10+0.05)))~log(Eucdist10))
plot(lm_Phi_Euc)
plot(lm_logRousPhi_logEuc)  #I think that untransformed distances look better
mantel(Eucdist10, PhiSTdist10, permutations=999)  #P=0.001
plot(Eucdist10, GSTdist10)
mantel(Eucdist10, GSTdist10, permutations=999)  #not signif
plot(Eucdist10, Jostdist10)
mantel(Eucdist10, Jostdist10, permutations=999)  #not signif


#create data frame for MDRM tests
temp<-read.table("PhiSt_N10.txt")  
alldists <- data.frame(t(combn(rownames(temp),2)), as.numeric(PhiSTdist10)) #makeing new dataframe
names(alldists) <- c("pop1", "pop2", "PhiST") #adding column names
alldists$GST<- as.numeric(GSTdist10) #adding new column
alldists$Jost<- as.numeric(Jostdist10)
alldists$Eucdist<- as.numeric(Eucdist10) 
alldists$OWdist<-as.numeric(OWdist10)
pairs(alldists)

#check that new data frame returns the same results as Mantel test
summary(lmp(formula = PhiST~Eucdist, data=alldists, perm="Prob")) #R^2 0.0668, Rmantel = 0.8166, SAME
summary(lmp(formula = GST~Eucdist, data=alldists, perm="Prob"))
summary(lmp(formula = Jost~Eucdist, data=alldists, perm="Prob"))
summary(lmp(formula = PhiST~OWdist, data=alldists, perm="Prob")) 
summary(lmp(formula = GST~OWdist, data=alldists, perm="Prob"))
summary(lmp(formula = Jost~OWdist, data=alldists, perm="Prob"))

#export, add dummy variables representing barriers to dataframe, reimport
#if my R skills were better I could add dummy variables with a for loop, but that will take too long right now
#will do it using perl and reimport
alldists$WSumatra<-1
alldists$Sunda<-1
alldists$Halma<-1
alldists$Pacific<-1
write.csv(alldists, file = "All.distances.csv")  #use perl script "dummy variables", also normalize all entries - mean 0, SD of 1

alldists<-read.csv("All.distances_dummy_variables.csv")

#univariate regressions with PhiST
summary(lmp(formula = PhiST~Eucdist, data=alldists, perm="Prob"))  #R2=0.6668 
summary(lmp(formula = PhiST~OWdist, data=alldists, perm="Prob"))  #R2=0.6638
summary(lmp(formula = PhiST~WSumatra, data=alldists, perm="Prob"))  #R2=0.003232 
summary(lmp(formula = PhiST~Sunda, data=alldists, perm="Prob"))  #R2=0.01007 
summary(lmp(formula = PhiST~Halma, data=alldists, perm="Prob"))  #R2=0.1063
summary(lmp(formula = PhiST~Pacific, data=alldists, perm="Prob"))  #R2=0.3837

#backward model sel with PhiST, ordered by univariate order
summary(lmp(formula = PhiST~Eucdist+OWdist+Pacific+Halma+Sunda+WSumatra, data=alldists, perm="Prob"))  #NEG values for Halma, Sunda
#remove least signif (Sunda - negative)
summary(lmp(formula = PhiST~Eucdist+OWdist+Pacific+Halma+WSumatra, data=alldists, perm="Prob"))  #NEG values for Halma, Sunda
#remove least signif (Halma - negative)
summary(lmp(formula = PhiST~Eucdist+OWdist+Pacific+WSumatra, data=alldists, perm="Prob"))  #NEG values for Halma, Sunda
#remove least signif (WSumatra - negative)
summary(lmp(formula = PhiST~Eucdist+OWdist+Pacific, data=alldists, perm="Prob"))  #NEG values for Halma, Sunda
#remove OWdist
summary(lmp(formula = PhiST~Eucdist+Pacific, data=alldists, perm="Prob"))  #NEG values for Halma, Sunda
#BOTH Eucdist and Pacific are signif, R2=0.686, P<2e-16 for each beta

#forward model selection first to add = Eucdist, then evaluate amount to enter
summary(lmp(formula = PhiST~Eucdist+OWdist, data=alldists, perm="Prob")) #OWdist not signif
summary(lmp(formula = PhiST~Eucdist+Pacific, data=alldists, perm="Prob")) #<2e-16 for Pacific, R2=.686
summary(lmp(formula = PhiST~Eucdist+Halma, data=alldists, perm="Prob")) # neg effect for Halma
summary(lmp(formula = PhiST~Eucdist+Sunda, data=alldists, perm="Prob")) # neg effect for Sunda
summary(lmp(formula = PhiST~Eucdist+WSumatra, data=alldists, perm="Prob")) #neg effect for WSum
#Finds SAME model as backwards model sel



#univariate regressions with Jost
summary(lmp(formula = Jost~Eucdist, data=alldists, perm="Prob"))  #R2 = 0.4583
summary(lmp(formula = Jost~OWdist, data=alldists, perm="Prob"))  #0.4669
summary(lmp(formula = Jost~WSumatra, data=alldists, perm="Prob"))  #NS
summary(lmp(formula = Jost~Sunda, data=alldists, perm="Prob"))  #NS 
summary(lmp(formula = Jost~Halma, data=alldists, perm="Prob"))  #0.1021
summary(lmp(formula = Jost~Pacific, data=alldists, perm="Prob"))  #0.2698

#forward model selection with Jost
summary(lmp(formula = Jost~OWdist+Eucdist, data=alldists, perm="Prob"))  #NS
summary(lmp(formula = Jost~OWdist+Pacific, data=alldists, perm="Prob"))  #P 0.0116 for Pacific
summary(lmp(formula = Jost~OWdist+Halma, data=alldists, perm="Prob"))  #NS
#OWdist + Pacific


#Plotting "IBD" outputs
#reimport file without normalized values
alldists<-read.csv("All.distances_dummy_variables_notnorm.csv")
#PhiST
plot(alldists$Eucdist, alldists$PhiST, type = 'n', xlab = "Euclidean Distance", ylab = "PhiST", xlim = c(0, 10000), ylim = c(-0.05,0.7))
within_ocean<-subset(alldists, Pacific == 0)
points(within_ocean$Eucdist, within_ocean$PhiST, type = 'p', pch=16, xlab = "", ylab = "", xlim = c(0, 10000), ylim = c(-0.05,0.7))
abline(lm(within_ocean$PhiST~within_ocean$Eucdist), col='black')
between_ocean<-subset(alldists, Pacific == 1)
points(between_ocean$Eucdist, between_ocean$PhiST, type = 'p' , xlab = "", ylab = "", xlim = c(0, 10000), ylim = c(-0.05,0.7))
abline(lm(between_ocean$PhiST~between_ocean$Eucdist), col='grey')

#Jost
plot(alldists$Eucdist, alldists$Jost, type = 'n', xlab = "Euclidean Distance", ylab = "Jost", xlim = c(0, 10000), ylim = c(-0.5,1))
points(within_ocean$Eucdist, within_ocean$Jost, type = 'p', pch=16, xlab = "", ylab = "", xlim = c(0, 10000), ylim = c(-0.5,1))
abline(lm(within_ocean$Jost~within_ocean$Eucdist), col='black')
points(between_ocean$Eucdist, between_ocean$Jost, type = 'p' , xlab = "", ylab = "", xlim = c(0, 10000), ylim = c(-0.5,1))
abline(lm(between_ocean$Jost~between_ocean$Eucdist), col='grey')

